aiapy documentation
===================

``aiapy`` is a Python package for analyzing data from the Atmospheric Imaging Assembly (AIA) instrument onboard the Solar Dynamics Observatory (SDO) spacecraft.

``aiapy`` includes software for converting AIA images from level 1 to level 1.5, point spread function deconvolution, and computing the wavelength and temperature response functions for the EUV channels.

.. grid:: 1 2 2 2
    :gutter: 3

    .. grid-item-card::
        :class-card: card

        Getting started
        ^^^^^^^^^^^^^^^

        .. toctree::
            :maxdepth: 1

            getting_started
            preparing_data
            generated/gallery/index
            code_ref/index

    .. grid-item-card::
        :class-card: card

        Other info
        ^^^^^^^^^^

        .. toctree::
            :maxdepth: 1

            citation
            changelog
            develop
